@@ -129,6 +129,7 @@ def get_profile(name):
 
 # Cache ########################################################################
 
+
 # A map from screen name to a list of ScreenCache objects. We ensure the cache
 # does not exceed config.screen_cache_size for each screen.
 predict_cache = collections.defaultdict(list)
@@ -156,6 +157,7 @@ class ScreenCache(object):
         if len(pc) > renpy.config.screen_cache_size:
             pc.pop(0)
 
+
 cache_put = ScreenCache
 
 
@@ -661,6 +663,7 @@ class ScreenDisplayable(renpy.display.layout.Container):
     def get_phase_name(self):
         return phase_name[self.phase]
 
+
 # The name of the screen that is currently being displayed, or
 # None if no screen is being currently displayed.
 _current_screen = None
@@ -678,6 +681,7 @@ def push_current_screen(screen):
 def pop_current_screen():
     _current_screen = current_screen_stack.pop()
 
+
 # A map from (screen_name, variant) tuples to screen.
 screens = { }
 
@@ -723,6 +727,7 @@ def get_all_screen_variants(name):
 
     return rv
 
+
 # Have all screens been analyzed?
 analyzed = False
 
@@ -751,6 +756,8 @@ def sort_screens():
     # For each screen, the set of screens that use it.
     reverse = collections.defaultdict(set)
 
+    names = { i[0] for i in screens }
+
     for k, v in screens.items():
 
         name = k[0]
@@ -762,6 +769,10 @@ def sort_screens():
             continue
 
         def callback(uses):
+
+            if uses not in names:
+                return
+
             depends[name].add(uses)
             reverse[uses].add(name)
 
@@ -920,8 +931,7 @@ def get_screen(name, layer=None):
     This can also take a list of names, in which case the first screen
     that is showing is returned.
 
-    This function can be used to check if a screen is showing, using code
-    like::
+    This function can be used to check if a screen is showing::
 
         if renpy.get_screen("say"):
             text "The say screen is showing."
@@ -1203,12 +1213,11 @@ def get_widget_properties(id, screen=None, layer=None):  # @ReservedAssignment
 
     Returns the properties for the widget with `id` in the `screen`
     on `layer`. If `screen` is None, returns the properties for the
-    current screen.
-
-    This can be used inside screen code.
+    current screen. This can be used from Python or property code inside
+    a screen.
 
     Note that this returns a dictionary containing the widget properties,
-    and so to get an individual property
+    and so to get an individual property, the dictionary must be accessed.
     """
 
     if screen is None:
